---
name: Usage question
about: Ask for help on how to best use `spatiomic`
title: ""
labels: help
assignees: ""
---

Ask for help on how to best use `biocontext_kb`. Prior to submitting your question, please read through the follwoing
resources:

- The BioContextAI documentation available at: [https://biocontext.ai](https://biocontext.ai)
- The `biocontext_kb` documentation available in the `README.md` file
